#!/bin/bash
#
# Usage: reheatStudies.sh -t date [-T ThresholdStartDate] [-r relativePriority] [-c]"
#
# This will recook studies having older access time in cache.reporitory than the specified date..
# The date shall be specified in an SQL compatible format (like "2021-11-18 21:53:43")
#

. $HOME/etc/setenv.sh
. $HOME/component/tools/scripttools.shi

NicemeTaskLimit=200;

threshold=0

if [ "$1" == "-t" ] ; then
        threshold=$2
        shift
        shift
else
        echo "usage: reheatStudies.sh -t ThresholdDate [-T ThresholdStartDate] [-r relativePriority] [-c]"
        echo "  Threshold dates shall be presented in a mysql compatible format, studies with acquisition date/time older then the ThresholdDate" 
        echo "  (and newer than ThreaholdStartDate if specified) will be processed. The generated tasks' relative priority is by default 110."
        echo "	-c: heat up studies missing from cache repository. Resource time will be set to RCVDATETIME"
        exit 1
fi

thresholdEnd="1000-01-01";
if [ "$1" == "-T" ] ; then
        thresholdEnd=$2
        shift
        shift
fi

relPri=110
if [ "$1" == "-r" ] ; then
	relPri=$2
	shift
	shift
fi

createMode="none"
if [ "$1" == "-c" ] ; then
	createMode="old"
	shift
fi
#echo "This script will recook studies having receive date older than $threshold".


#between is inclusive, but should not matter much as a date is always exact
echo sql.sh "select count(STYIUID), ' studies,', SUM(NUMOFOBJ), ' objects' from Dcstudy where RCVDATETIME BETWEEN '$thresholdEnd' and '$threshold'" -N
sql.sh "select count(STYIUID), ' studies,', SUM(NUMOFOBJ), ' objects' from Dcstudy where RCVDATETIME BETWEEN '$thresholdEnd' and '$threshold'" -N

read -p "Are you sure (y/n)? " -n 1 -r
if [[ ! $REPLY =~ ^[Yy]$ ]]
then
       echo
    exit 1
fi
echo


echo STARTING
date

sql.sh "select STYIUID from Dcstudy where RCVDATETIME BETWEEN '$thresholdEnd' and '$threshold' order by RCVDATETIME" -N |while read -r study ; do
#$REPOSITORYHANDLER_HOME/bin/listDirectories $REPOSITORY_CACHE  | while read -r study ; do
#       cnt=`$TOOLS_HOME/sql.sh "select count(*) from Dcstudy where STYIUID='$study' AND RCVDATETIME<'$threshold'" -N`
        loc=`$REPOSITORYHANDLER_HOME/bin/locateResource $REPOSITORY_CACHE $study -t`
        ret=$?
        if [ $ret -lt 0 ] ; then
                echo "the following command exited with $ret : $REPOSITORYHANDLER_HOME/bin/locateResource $REPOSITORY_CACHE $study -t"
                continue
        fi
        if [ $ret -eq 4 ] && [ "$createMode" == "old" ] ; then
        	loc=`$REPOSITORYHANDLER_HOME/bin/createDirectory $REPOSITORY_CACHE $study`
        	rcvdt=`sql.sh "select RCVDATETIME from Dcstudy where STYIUID='$study'" -N`
        	touch -d "$rcvdt" $loc
        fi
        if [ "$loc" != "" ] ; then
                niceme && break
                echo "Processing $loc"
                #rm $loc/*.erblb $loc/herpa-OBJECT.bin
                $TASKD_HOME/runjavacmd -c "0 imagemed.util.ReheatStarter -s $study -p -r $relPri -R"
                #sleep 0.1
        else
                echo "Skipping (not in cache) $study"
        fi
done

echo FINISHED
date
